==> zdl-1.0.tar.gz: zdl-1.0/extensions/nowvideo.sh <==
#!/bin/bash -i
#
# ZigzagDownLoader (ZDL)
# 
# This program is free software: you can redistribute it and/or modify it 
# under the terms of the GNU General Public License as published 
# by the Free Software Foundation; either version 3 of the License, 
# or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, 
# but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
# or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License 
# along with this program. If not, see http://www.gnu.org/licenses/. 
# 
# Copyright (C) 2011: Gianluca Zoni (zoninoz) <zoninoz@inventati.org>
# 
# For information or to collaborate on the project:
# https://savannah.nongnu.org/projects/zdl
# 
# Gianluca Zoni (author)
# http://inventati.org/zoninoz
# zoninoz@inventati.org
#

## ZDL add-on
## zdl-extension types: streaming
## zdl-extension name: Nowvideo

if [ "$url_in" != "${url_in//'nowvideo.'}" ] &&
       [ "$url_in" != "${url_in//video}" ]
then
    myip=$(wget -t 1 -T $max_waiting -qO- http://indirizzo-ip.com/ip.php)
    html=$(wget -t 1 -T $max_waiting                 \
		"$url_in"                            \
		--user-agent="$user_agent"           \
		-qO-)

    if [ -n "$html" ]
    then
	test_exist=$(grep "This file no longer exists on our servers" <<< "$html")

	if [ -n "$test_exist" ]
	then
	    _log 3

	else
	    if [[ "$html" =~ (Continue to the video) ]]
	    then
		input_hidden "$html"

		html=$(wget -t 1 -T $max_waiting                     \
			    "$url_in"                                \
			    --user-agent="$user_agent"               \
			    --post-data="${post_data}&submit=submit" \
			    -qO-)
	    fi
	    
	    flashvars_file=$(grep "flashvars.file=" <<< "$html")
	    flashvars_file="${flashvars_file#*'flashvars.file='\"}"
	    flashvars_file="${flashvars_file%\"*}"

	    flashvars_key=$(grep "$myip" <<< "$html")
	    flashvars_key="${flashvars_key#*\"}"
	    flashvars_key="${flashvars_key%\"*}"
	    flashvars_domain=$(grep "flashvars.domain=" <<< "$html")
	    flashvars_domain="${flashvars_domain#*'flashvars.domain='\"}"
	    flashvars_domain="${flashvars_domain%\"*}"

	    rm -f "$path_tmp"/zdl2.tmp
	    axel "${flashvars_domain}/api/player.api.php?user=undefined&cid=1&file=${flashvars_file}&pass=undefined&key=${flashvars_key}" -o "$path_tmp"/zdl2.tmp &>/dev/null

	    if [ ! -f "$path_tmp"/zdl2.tmp ]
	    then
		_log 5
		
	    elif [ -n "$(grep 'The video is being transfered' "$path_tmp"/zdl2.tmp)" ]
	    then
		_log 17
		
	    elif [ -z $(cat "$path_tmp"/zdl2.tmp 2>/dev/null |grep url ) ]
	    then
		not_available=true
		break_loop=true
	    else
		url_in_file=$(cat "$path_tmp"/zdl2.tmp)
		url_in_file="${url_in_file#*'url='}"
		url_in_file="${url_in_file%%'&'*}"

		ext="${url_in_file##*'.'}"
		file_in=$(grep "share" <<< "$html" |grep "title=")
		file_in="${file_in#*'title='}"
		file_in="${file_in%%\"*}.$ext"
	    fi
	fi
    else
	_log 2
    fi
fi

==> zdl-2.0.tar.gz: zdl-2.0/extensions/nowvideo.sh <==
#!/bin/bash -i
#
# ZigzagDownLoader (ZDL)
# 
# This program is free software: you can redistribute it and/or modify it 
# under the terms of the GNU General Public License as published 
# by the Free Software Foundation; either version 3 of the License, 
# or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, 
# but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
# or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License 
# along with this program. If not, see http://www.gnu.org/licenses/. 
# 
# Copyright (C) 2011: Gianluca Zoni (zoninoz) <zoninoz@inventati.org>
# 
# For information or to collaborate on the project:
# https://savannah.nongnu.org/projects/zdl
# 
# Gianluca Zoni (author)
# http://inventati.org/zoninoz
# zoninoz@inventati.org
#

## ZDL add-on
## zdl-extension types: streaming
## zdl-extension name: Nowvideo
    
if [[ "$url_in" =~ nowvideo\. ]]
then
    if [[ "$url_in" =~ fastredirect ]]
    then
        replace_url_in "${url_in//'api/fastredirect/streaming.php?file_real='/play/}"
    fi

    html=$(curl -s \
		-c "$path_tmp"/cookies.zdl \
		"$url_in")
    
    input_hidden "$html"

    action_url="${url_in//\/play\///videos/}"

    html=$(curl -s \
		-b "$path_tmp"/cookies.zdl \
		-d "$post_data" \
		"$action_url")

    url_in_file=$(unpack "$html")

    url_in_file="${url_in_file#*\'}"
    url_in_file="${url_in_file%%\'*}"

    file_in=$(get_title "$html")
    file_in="${file_in#Nowvideo }".${url_in_file##*.}
    
    end_extension
fi
